@@ -3,8 +3,7 @@ from .helpers import generate_attribute_string
 class Device():
     """Represent Device config."""
 
-    def __init__(self, raw, request):
-        self._raw = raw
+    def __init__(self, request):
         self._request = request
 
     def __str__(self):
@@ -12,6 +11,8 @@ class Device():
         return generate_attribute_string(self, attributes)
 
     def __eq__(self, other: object) -> bool:
+        if (other == None):
+            return False
         return self._raw == other._raw
 
     @property
@@ -42,4 +43,7 @@ class Device():
     async def update(self):
         status, response = await self._request('get', 'api')
         if status == 200 and response:
-            self._raw = response
\ No newline at end of file
+            self._raw = response
+            return True
+            
+        return False
